/// <reference types="react" />
export type FormState<T> = {
    [K in keyof T]: T[K];
};
export type ValidatorFn = (value: string | boolean | File | number | null) => boolean;
export type FormValidation = {
    [key: string]: [ValidatorFn, string];
};
export type ValueInput = string | boolean | File | number | null;
export type FormValidationState = {
    [key: string]: string | null;
};
export interface ChangeEvent {
    target: {
        name: string;
        value: any;
        type?: string;
        checked?: boolean;
        files?: FileList;
    };
}
export interface FocusEvent {
    target: {
        name: string;
    };
}
export interface FormProps<TFieldValues> {
    onSubmit: (data: FormState<TFieldValues>) => Promise<void>;
    initialForm: FormState<TFieldValues>;
    formValidations: FormValidation;
}
export interface MyChangeEvent extends React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement | HTMLSelectElement> {
}
export interface MyFocusEvent extends React.FocusEvent<HTMLInputElement | HTMLTextAreaElement | HTMLSelectElement> {
}
export declare const isStringValue: (value: unknown) => value is string;
export declare const isNumberValue: (value: unknown) => value is number;
export declare const isBooleanValue: (value: unknown) => value is boolean;
export declare const isRegExp: (value: unknown) => value is RegExp;
export declare const isFunction: (value: unknown) => value is Function;
export declare const isObject: (value: unknown) => value is Record<string, any>;
export declare const isArray: (value: unknown) => value is any[];
export declare const isDate: (value: unknown) => value is Date;
export declare const isFile: (value: unknown) => value is File;
export declare const isBlob: (value: unknown) => value is Blob;
export declare const isNull: (value: unknown) => value is null;
export declare const isUndefined: (value: unknown) => value is undefined;
export declare const isNullish: (value: unknown) => value is null | undefined;
export declare const isTruthy: (value: unknown) => boolean;
export declare const isFalsy: (value: unknown) => boolean;
